" This file is part of the vim-noweb package.
" Copyright (c) 2023, 2024 Edward K. McGuire.
" It was compiled from vim-noweb.nw using Norman Ramsey's Noweb.
" Last commit $Date: Fri Oct 13 20:23:21 2023 +0000 $
if exists("b:current_syntax") | finish | endif
syntax include @SyntaxTeX syntax/tex.vim
unlet b:current_syntax
syntax region Normal start=/\v%^/ end=/\v%$/ contains=@SyntaxTeX
function NowebRecognize( language, pattern, file )
	execute 'syntax match nowebCodeChunkDecl' . a:language
		\ . ' "\v^[<][<]' . a:pattern . '[>][>][=]\s*$"'
		\ . ' skipnl'
		\ . ' containedin=@SyntaxTeX'
		\ . ' contains=nowebCodeQuotation'
		\ . ' nextgroup=nowebCodeChunkBody' . a:language
	execute 'highlight link nowebCodeChunkDecl' . a:language . ' PreProc'
	execute 'syntax include @Syntax' . a:language . ' syntax/' . a:file
	execute 'unlet b:current_syntax'
	execute 'syntax region nowebCodeChunkBody' . a:language
		\ . ' keepend'
		\ . ' start="\v.*"'
		\ . ' end="\v^([@]($| ))|([<][<].*[>][>][=][ \t]*$)"me=s-1'
		\ . ' contained'
		\ . ' contains=nowebCodeUse,@Syntax' . a:language
endfunction
syntax match PreProc "\v^[@]($| [%]def .*| )" containedin=@SyntaxTeX
syntax region nowebCodeQuotation matchgroup=Operator
	\ start="\v[@]@<!\[\["
	\ end="\v\]\]"
	\ containedin=@SyntaxTeX
	\ contains=nowebCodeUse,nowebCodeQuotation
highlight link nowebCodeQuotation String
syntax match nowebCodeChunkDecl "\v^[<][<].*[>][>][=][ \t]*$"
	\ skipnl
	\ containedin=@SyntaxTeX
	\ contains=nowebCodeQuotation
	\ nextgroup=nowebCodeChunkBody
highlight link nowebCodeChunkDecl PreProc
syntax region nowebCodeChunkBody
	\ start="\v.*"
	\ end="\v^([@]($| ))|([<][<].*[>][>][=][ \t]*$)"me=s-1
	\ contained
	\ contains=nowebCodeUse
highlight link nowebCodeChunkBody String
call NowebRecognize( 'Awk'     ,     '.*\.awk(|\s.*)' ,     'awk.vim' )
call NowebRecognize( 'Bash'    ,    '.*\.bash(|\s.*)' ,    'bash.vim' )
call NowebRecognize( 'Crontab' , '.*\.crontab(|\s.*)' , 'crontab.vim' )
call NowebRecognize( 'Gnuplot' ,      '.*\.gp(|\s.*)' , 'gnuplot.vim' )
call NowebRecognize( 'Make'    , '[mM]akefile(|\s.*)' ,    'make.vim' )
call NowebRecognize( 'Man'     ,    '.*\.[18](|\s.*)' ,     'man.vim' )
call NowebRecognize( 'Python'  ,      '.*\.py(|\s.*)' ,  'python.vim' )
call NowebRecognize( 'Sed'     ,     '.*\.sed(|\s.*)' ,     'sed.vim' )
call NowebRecognize( 'Sh'      ,      '.*\.sh(|\s.*)' ,      'sh.vim' )
" call NowebRecognize( 'C'     ,       '.*\.c(|\s.*)' ,       'c.vim' )
" call NowebRecognize( 'Perl'  ,      '.*\.pl(|\s.*)' ,    'perl.vim' )
" call NowebRecognize( 'Vim'   ,     '.*\.vim(|\s.*)' ,     'vim.vim' )
syntax match nowebCodeUse "\v[@]@<![<][<].{-}[>][>]"
	\ contained
	\ contains=nowebCodeQuotation
highlight link nowebCodeUse Identifier
let b:current_syntax = "noweb"
